@@ -4,7 +4,7 @@ package Directory::Organize;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('v0.9.9');
+use version; our $VERSION = qv('0.8');
 
 sub new {
     my $self = shift;
@@ -257,7 +257,7 @@ Directory::Organize - create and find directories organized by date
 
 =head1 VERSION
 
-This documentation refers to Directory::Organize version v0.9.9.
+This documentation refers to Directory::Organize version 0.8.
 
 =head1 SYNOPSIS
 
@@ -287,10 +287,7 @@ This documentation refers to Directory::Organize version v0.9.9.
 
 This functions returns an array of arrays of the form
 
-  ([ path1, description1 ],
-   ...
-   [ pathn, descriptionn ],
-  )
+  [ I<path>, I<description> ].
 
 It searches all subdirectories three levels below C<$basedir> for a file
 named I<.project>. The returned array contains the relative path from the
